#
# spec file for package sslh
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2012 by Lars Vogdt
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sslh
Version:        1.22c
Release:        2.5
Summary:        SSL/SSH multiplexer
License:        GPL-2.0-or-later
Group:          Productivity/Networking/SSH
URL:            https://www.rutschle.net/tech/sslh.shtml
Source:         https://www.rutschle.net/tech/%{name}/%{name}-v%{version}.tar.gz
Source1:        %{name}.init
Source2:        %{name}.sysconfig
Source3:        %{name}.conf.d
BuildRequires:  libcap-devel
BuildRequires:  libconfig-devel
BuildRequires:  pcre2-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libsystemd)
Requires:       openssh
Requires:       openssl
Requires(pre):  group(nobody)
%systemd_requires

%description
sslh lets one accept both HTTPS and SSH connections on the same port. It makes
it possible to connect to an SSH server on port 443 (e.g. from inside a
corporate firewall) while still serving HTTPS on that port.

%prep
%autosetup -n %{name}-v%{version} -p1

%build
export CFLAGS="%{optflags}"
%make_build PREFIX=%{_prefix} DESTDIR=%{buildroot}

%install
make PREFIX=%{_prefix} DESTDIR=%{buildroot} install

install -Dm644 scripts/systemd.%{name}.service %{buildroot}%{_unitdir}/%{name}.service
install -Dm644 %{SOURCE3} %{buildroot}%{_sysconfdir}/conf.d/%{name}
ln -sf %{_sbindir}/service %{buildroot}/%{_sbindir}/rc%{name}

# install default configuration
mkdir -p %{buildroot}%{_sysconfdir}/default
cp scripts/etc.sysconfig.%{name} %{buildroot}%{_sysconfdir}/default/%{name}

%pre
getent passwd sslh || useradd  -r -g nogroup -s /bin/false -c "User for SSLH" -d %{_localstatedir}/lib/empty sslh
%service_add_pre sslh.service

%post
%service_add_post sslh.service

%preun
%service_del_preun sslh.service

%postun
%service_del_postun sslh.service

%files
%doc ChangeLog README.md
%{_sbindir}/%{name}
%{_sbindir}/rc%{name}
%{_unitdir}/%{name}.service
%dir %{_sysconfdir}/conf.d
%config(noreplace) %{_sysconfdir}/conf.d/%{name}
%config(noreplace) %{_sysconfdir}/default/%{name}
%{_mandir}/man8/%{name}.8%{?ext_man}

%changelog
* Tue May  3 2022 Marcus Meissner <meissner@suse.com>
- switch to https source url
* Mon Sep  6 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.22c:
  * Fix invalid size (#302)
  * Test aborted connections (#285)
* Wed Aug 25 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.22b:
  * do not timeout TCP connections (fix #300)
  * remove obsolete usage string and added lost version option
  * be more defensive when allocating and extending gap
* Wed Aug 18 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.22:
  * sslh-select now supports UDP protocols.
    Probes specified in the `protocols`
    configuration entry are tried on incoming packets,
    TCP or UDP, and forwarded based on the input
    protocol (an incoming TCP connection will be
    forwarded as TCP, and same with UDP).
    This has been tested with DNS as shown in udp.cfg:
    incoming packets that contain my domain name are
    assumed to be a DNS request and forwarded
    accordingly. Note this could cause problems if
    combined with incoming TLS with SNI.  UDP clients
    and servers need to agree on the IPv4/IPv6 they use:
    use the same protocol on all sides! Often, this
    means explicitely using 'ip4-localhost'.
    UDP sender-receiver pairs (connections, so to speak)
    are kept for 60s, which can be changed with
    `udp_timeout` in the configuration.
  * Added probes for UDP protocols QUICK and Teamspeak.
  * Added probes for syslog protocol.
  * sslh-select refactored to change linear searches
  through connections to linear searches through
  fd_set.
  * Fixed a libconfig call to support libconfig 1.7.3.
  * Added symbol to support libconfig 1.4.9, still in
  use in CentOS7.
  * Warn about unknown settings in the configuration
  file.
  * Added per-protocol `transparent` option. sslh-fork
  drops the capability after creating the server-side
  transparent socket. Transparent now uses CAP_NET_RAW
  instead of CAP_NET_ADMIN.
  * Removed compile-time option to use POSIX regex. Now
  regex must be PCRE2 (Perl-Compatible). This was in
  fact the case since v1.21, as PCRE are used to parse
  the config file.
- Drop sslh-nopcreposix.patch:
  pcre2 is a hard dependency now
* Fri Apr  9 2021 Cristian Rodríguez <crrodriguez@opensuse.org>
- remove unused tcpd-devel dependency
* Fri Apr  9 2021 Cristian Rodríguez <crrodriguez@opensuse.org>
- sslh-nopcreposix.patch: Using pcreposix is the wrong thing
  to do on any glibc based system, avoid linking it.
* Fri Jul 31 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.21c:
  * Removed support for 'ssl' and fix a related segfault bug.
* Mon Jul 20 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.21b:
  * Moved configuration and command-line management to
    use conf2struct. Changes are:
  - command line option <-F|--config> no longer defaults to
  /etc/sslh.cfg, so you have to specify it explicitly.
  - command line option <-v|--verbose> takes a mandatory
  integer parameter
  * Changed exit code for illegal command line parameter
  from 1 to 6 (for testing purposes)
* Mon Jul 13 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.21:
  * Added TCP_FASTOPEN support for client sockets (if
    tfo_ok is specified in their configuration) and for
    listenint socket, if all client protocols support it.
  * Added 'minlength' option to skip a probe if less
    than that many bytes have been received (mostly for
    regex)
  * Moved configuration and command-line management to
    use conf2struct. Hopefully this should be transparent
    to users.
  * Update Let's Encrypt entry in example.cfg for tls-alpn-01
    challenges; tls-sni-* challenges are now deprecated.
  * Log to syslog even if in foreground (for people who
    use fail2ban)
  * Use syslog_facility: "none" to disable syslog
    output.
* Wed Jan 15 2020 Ismail Dönmez <idonmez@suse.com>
- Cleanup spec file, remove old openSUSE support
- Fix useradd syntax
* Fri Nov 23 2018 mvetter@suse.com
- Update to 1.20:
  * Added support for socks5 protocol (Eugene Protozanov)
  * New probing method
  * Test suite refactored
- ChangeLog from 1.19:
  * Added ‘syslog_facility’ configuration option to specify where to log.
  * TLS now supports SNI and ALPN (Travis Burtrum), including support for Let’s Encrypt challenges (Jonathan McCrohan)
  * ADB probe. (Mike Frysinger)
  * Added per-protocol ‘fork’ option. (Oleg Oshmyan)
  * Added chroot option. (Mike Frysinger)
  * A truckload of bug fixes and documentation improvements (Various contributors)
- Remove filepath-in-systemd-service.patch: upstreamed
- Add BuildRequires: pcre-devel
* Mon Nov  6 2017 chris@computersalat.de
- fix systemd vs SysVinit
  * don't install both when system should be used
  * add var has_systemd
* Tue Jul 19 2016 jsegitz@novell.com
- Update to 1.18
  * Added USELIBPCRE to make use of regex engine optional.
  * Added support for RFC4366 SNI and RFC7301 ALPN
    (Travis Burtrum)
  * Changed connection log to include the name of the probe that
    triggered.
  * Changed configuration file format: 'probe' field is
    no longer required, 'name' field can now contain
    'tls' or 'regex', with corresponding options (see
    example.cfg)
  * Added 'log_level' option to each protocol, which
    allows to turn off generation of log at each
    connection.
  * Added 'keepalive' option.
  Version 1.17
  * Support RFC5952-style IPv6 addresses, e.g. [::]:443.
  * Transparant proxy support for FreeBSD  (Ruben van Staveren)
  * Using -F with no argument will try
    /etc/sslh/sslh.cfg and then /etc/sslh.cfg as configuration files.
    (argument to -F can no longer be separated from the option by a space,
    e.g. must be -Ffoo.cfg)
  * Call setgroups() before setgid() (fixes potential
    privilege escalation) (Lars Vogdt)
  * Use portable way of getting modified time for OSX support (Aaron
    Madlon-Kay)
  * Example configuration for fail2ban (Every Mouw)
- Dropped missing-call-to-setgroups-before-setuid.patch, included
  upstream
* Thu Dec 18 2014 jsegitz@novell.com
- Added filepath-in-systemd-service.patch to point to correct
  patch in systemd service file
* Tue Mar 25 2014 lars@linux-schulserver.de
- update to 1.16:
  + Probes made more resilient, to incoming data
    containing NULLs. Also made them behave properly
    when receiving too short packets to probe on the
    first incoming packet.
    (Ondrej Kuzník)
  + Libcap support: Keep only CAP_NET_ADMIN if started
    as root with transparent proxying and dropping
    priviledges (enable USELIBCAP in Makefile). This
    avoids having to mess with filesystem capabilities.
    (Sebastian Schmidt/yath)
  + Fixed bugs related to getpeername that would cause
    sslh to quit erroneously (getpeername can return
    actual errors if connections are dropped before
    getting to getpeername).
  + Set IP_FREEDBIND if available to bind to addresses
    that don't yet exist.
- compile with libcap support
- added missing-call-to-setgroups-before-setuid.patch
- removed patches fixed upstream:
  + sslh-asprintf.patch
  + sslh-chroot.patch
* Sun Dec 22 2013 rob.verduijn@gmail.com
- added /etc/conf.d/sslh
  now the service actually starts when using systemd
* Wed Dec 11 2013 rob.verduijn@gmail.com
- update to 1.15:
  + Added --transparent option for transparent proxying. See README for iptables magic and capability management.
  + Fixed bug in sslh-select: if number of opened file descriptor became bigger than FD_SETSIZE, bad things would happen.
  + Fixed bug in sslh-select: if socket dropped while defered_data was present, sslh-select would crash.
  + Increased FD_SETSIZE for Cygwin, as the default 64 is too low for even moderate load.
    Thanks to Arnaud Gendre and Michael K. Avanessian for helping with investigation of the last three points.
* Sun Jan  6 2013 lars@linux-schulserver.de
- update to 1.14:
  + Corrected OpenVPN probe to support pre-shared secret
    mode (OpenVPN port-sharing code is... wrong). Thanks
    to Kai Ellinger for help in investigating and
    testing.
  + Added an actual TLS/SSL probe.
  + Added configurable --on-timeout protocol
    specification.
  + Added a --anyprot protocol probe (equivalent to what
  - -ssl was).
  + Makefile respects the user's compiler and CFLAG
    choices (falling back to the current values if
    undefined), as well as LDFLAGS.
    (Michael Palimaka)
  + Added "After" and "KillMode" to systemd.sslh.service
    (Thomas Weißschuh).
- use upstream sslh.systemd.service instead of own one
* Thu Aug 23 2012 lars@linux-schulserver.de
- update to 1.13b:
  + WARNING: Options changed, you'll need to update your start-up
    scripts! Log format changed, you'll need to update log
    processing scripts
  + Added support for configuration file.
  + New protocol probes can be defined using regular expressions that
    match the first packet sent by the client.
  + Added HTTP probe.
  + Now supports IPv6 throughout (both on listening and forwarding)
  + Logs now contain IPv6 addresses, local forwarding address, and
    resolved names (unless --numeric is specified).
  + Introduced long options.
  + Bind to multiple addresses with multiple -p options.
  + Added -o "OpenVPN" and OpenVPN probing and support.
  + Added -f "foreground" option.
- adapted init script to new options
- added option for openVPN target address in sysconfig file
  For openSUSE > 12.1:
- added config file /etc/default/sslh - but this needs to be enabled/
  added in SSLH_OPTS="" in /etc/sysconfig/sslh for now as the
  sysconfig file already contains all variables
- added systemd file
* Wed Aug 18 2010 lars@linux-schulserver.de
- add special user sslh for sslh daemon
- fix typo in init script
* Wed Aug 18 2010 lars@linux-schulserver.de
- use /etc/sysconfig/sslh for configuration
- enhanced the init script
* Mon Jun 28 2010 lars@linux-schulserver.de
- specfile cleanup
- package docu and manpage
- create rcsslh symlink
- build with distribution optflags
- added sslh-1.7a-asprintf.patch
* Thu Feb 25 2010 Christian Debertshaeuser <webcd@online.de>
- initial build
